## pyBOAT - A Biological Oscillations Analysis Toolkit ##


Tools for time-frequency analysis of noisy non-stationary signals with Morlet Wavelets.
See the github repo for general documentation or
[this paper](https://www.biorxiv.org/content/10.1101/2020.04.29.067744v3)
for more details.

**Contributers are welcome!**

### Features ###

* Optimal sinc filter
* Fourier analysis
* Wavelet analysis 
* Ridge detection
* Phase extraction
* Amplitude estimation
* Synthetic signal generator
* Ensemble readouts
